@@ -116,8 +116,7 @@ use strict;
     PVIP_NODE_TRUE
     PVIP_NODE_TW_VM
     PVIP_NODE_HAS
-    PVIP_NODE_PRIVATE_ATTRIBUTE
-    PVIP_NODE_PUBLIC_ATTRIBUTE
+    PVIP_NODE_ATTRIBUTE_VARIABLE
     PVIP_NODE_FUNCREF
     PVIP_NODE_PATH
     PVIP_NODE_TW_PACKAGE
@@ -164,6 +163,16 @@ use strict;
     PVIP_NODE_NOT_DIVISIBLE_BY
     PVIP_NODE_CONTAINER_IDENTITY
     PVIP_NODE_Z
+    PVIP_NODE_SUBMETHOD
+    PVIP_NODE_BINDAND_MAKE_READONLY
+    PVIP_NODE_LIST_ASSIGNMENT
+    PVIP_NODE_TW_A
+    PVIP_NODE_TW_B
+    PVIP_NODE_TW_C
+    PVIP_NODE_SO
+    PVIP_NODE_GCD
+    PVIP_NODE_KEEP
+    PVIP_NODE_UNDO
     PVIP_CATEGORY_UNKNOWN
     PVIP_CATEGORY_STRING
     PVIP_CATEGORY_INT
